@@ -148,7 +148,11 @@ SEXP TransPROBAJ(
 		int *index1 = (int*)malloc( len*sizeof(int) ); // allocate memory block
 		double *WORK0 = (double*)malloc( len*sizeof(double) ); // allocate memory block
 		int *WORK1 = (int*)malloc( len*sizeof(int) ); // allocate memory block
+		#ifdef _OPENMP
 		unsigned int iseed = (unsigned int)time(NULL) ^ (unsigned int)omp_get_thread_num(); // save per thread seed
+		#else
+		unsigned int iseed = (unsigned int)time(NULL);
+		#endif
 		srand(iseed); // set seed
 		#ifdef _OPENMP
 		#pragma omp single
